==> rHVDM_1.4.0.tar.gz: rHVDM/man/HVDMcheck.Rd <==
\name{HVDMcheck}

\alias{HVDMcheck}

\title{Checks that an object of class ExpressionSet is compliant with HVDM}
\description{
  This method issues warnings about the compliance of the ExpressionSet object to be used with rHVDM.
  It just issues warnings and does not attempt to correct the problems encountered. the \code{pdata} argument
  is optional; if missing, the method will check the phenodata that is inside
  the ExpressionSet.
}
\usage{
HVDMcheck(eset,pdata)
}
\arguments{
  \item{eset}{ an ExpressionSet object (Biobase) }
  \item{pdata}{ a dataframe (optional argument) }
}
\details{ The checks performed are: A) the phenoData has all the required fields. B) the time field is numeric, has
  a zero time point, does not have negative or repeated values. C) the row names in the phenoData 
  are consistent with the columns names found in the exprSet. D) the data is not log-transformed.
  E) Standard deviations have been supplied in the ExpressionSet, and they are non-negative.
}

\value{
	no value returned.  
}
\references{ 
M. Barenco, D. Tomescu, D. Brewer, R. Callard, J. Stark, M. Hubank (2006) Ranked predictions
of p53 targets using Hidden Variable Dynamic Modelling. \emph{Genome Biology}, \bold{V7(3)}, R25.
}
\author{ Martino Barenco }

\note{ If the \code{pdata} argument is ignored (it can be), 
the method checks the phenoData that is inside the ExpressionSet.}

\seealso{\code{\link{training}}}

\examples{
data(HVDMexample)
HVDMcheck(fiveGyMAS5)
}
\keyword{ IO }
\keyword{ ts }

==> rHVDM_1.32.0.tar.gz: rHVDM/man/HVDMcheck.Rd <==
\name{HVDMcheck}

\alias{HVDMcheck}

\title{Checks that an object of class ExpressionSet is compliant with HVDM}
\description{
  This method issues warnings about the compliance of the ExpressionSet object to be used with rHVDM.
  It just issues warnings and does not attempt to correct the problems encountered. the \code{pdata} argument
  is optional; if missing, the method will check the phenodata that is inside
  the ExpressionSet.
}
\usage{
HVDMcheck(eset,pdata)
}
\arguments{
  \item{eset}{ an ExpressionSet object (Biobase) }
  \item{pdata}{ a dataframe (optional argument) }
}
\details{ The checks performed are: A) the phenoData has all the required fields. B) the time field is numeric, has
  a zero time point, does not have negative or repeated values. C) the row names in the phenoData 
  are consistent with the columns names found in the ExpressionSet. D) the data are not log-transformed.
  E) Standard deviations have been supplied in the ExpressionSet, and they are non-negative.
}

\value{
	no value returned.  
}
\references{ 
M. Barenco, D. Tomescu, D. Brewer, R. Callard, J. Stark, M. Hubank (2006) Ranked predictions
of p53 targets using Hidden Variable Dynamic Modelling. \emph{Genome Biology}, \bold{V7(3)}, R25.
}
\author{ Martino Barenco }

\note{ If the \code{pdata} argument is ignored (it can be), 
the method checks the phenoData that is inside the ExpressionSet.}

\seealso{\code{\link{training}}}

\examples{
data(HVDMexample)
HVDMcheck(fiveGyMAS5)
}
\keyword{ IO }
\keyword{ ts }
